﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Shapes;

namespace pivot
{
    enum Shape
    {
        Point,
        Line,
        Triangle,
        Square,
        Rectangle,
        Trapezoid,
        Pentagon
    }

    class DataAccess
    {
        public static DataView GetDataTable(int count)
        {
            DataTable dt = new DataTable("BusinessObjectsDataTable");
            PropertyDescriptorCollection pdc = TypeDescriptor.GetProperties(typeof(BusinessObject));
            foreach (PropertyDescriptor pd in pdc)
            {
                dt.Columns.Add(new DataColumn(pd.Name, pd.PropertyType));
            }
            BusinessObjectCollection list = BusinessObjectCollection.GetList(count);
            foreach (BusinessObject bo in list)
            {
                DataRow dr = dt.NewRow();
                foreach (PropertyDescriptor pd in pdc)
                {
                    dr[pd.Name] = pd.GetValue(bo);
                }
                dt.Rows.Add(dr);
            }
            return dt.DefaultView;
        }
    }

    class BusinessObjectCollection : List<BusinessObject>
    {
        private static Random r = new Random(1123);
        public static BusinessObjectCollection GetList(int count)
        {
            BusinessObjectCollection list = new BusinessObjectCollection();
            DateTime date0 = DateTime.Now;
            DateTime date1 = DateTime.Now;
            int k;
            int clientCount = 245;
            int campaignCount = 5;
            int yearCount = 5;
            int colorCount = 5;
            int shapeCount = 5;

            for (int i = 0; i < count; ++i)
            {
                list.Add(new BusinessObject()
                {
                    Id = i,
                    Client = string.Format("cli_{0}", k = r.Next(clientCount)),
                    // Campaign = string.Format("cam_{0}", r.Next(campaignCount)),
                    Campaign = string.Format("cam_{0}", k + r.Next(campaignCount)),
                    Date = date1 = new DateTime(date0.Year - r.Next(yearCount), r.Next(12) + 1, 1),
                    Date1 = date1,
                    Color = string.Format("col_{0}", r.Next(colorCount)),
                    Shape = string.Format("sha_{0}", r.Next(shapeCount)),
                    ColH = string.Format("H_{0}", r.Next(100)),
                    ColI = string.Format("I_{0}", r.Next(100)),
                    ColJ = string.Format("J_{0}", r.Next(100)),
                    Price = (int)(100000 * r.NextDouble()) / 100,
                    Spend = (int)(100000 * r.NextDouble()) / 100,
                    Quantity = r.Next(1000) + 100
                });
            }
            return list;
        }
    }

    class BusinessObject
    {
        string client = string.Empty;
        string campaign = string.Empty;
        DateTime date = DateTime.Now;
        DateTime date1 = DateTime.Now;
        string color = string.Empty;
        string shape = string.Empty;
        string colH = string.Empty;
        string colI = string.Empty;
        string colJ = string.Empty;
        double price;
        double spend;
        int quantity;
        int id;

        public string Client
        {
            get { return this.client; }
            set { this.client = value; this.OnPropertyChanged("Client"); }
        }

        public string Campaign
        {
            get { return this.campaign; }
            set { this.campaign = value; this.OnPropertyChanged("Campaign"); }
        }

        public DateTime Date
        {
            get { return this.date; }
            set { this.date = value; this.OnPropertyChanged("Date"); }
        }

        public DateTime Date1
        {
            get { return this.date1; }
            set { this.date1 = value; this.OnPropertyChanged("Date1"); }
        }

        public string Color
        {
            get { return this.color; }
            set { this.color = value; this.OnPropertyChanged("Color"); }
        }

        public string Shape
        {
            get { return this.shape; }
            set { this.shape = value; this.OnPropertyChanged("Shape"); }
        }

        public string ColH
        {
            get { return this.colH; }
            set { this.colH = value; this.OnPropertyChanged("ColH"); }
        }

        public string ColI
        {
            get { return this.colI; }
            set { this.colI = value; this.OnPropertyChanged("ColI"); }
        }

        public string ColJ
        {
            get { return this.colJ; }
            set { this.colJ = value; this.OnPropertyChanged("ColJ"); }
        }

        public double Price
        {
            get { return this.price; }
            set { this.price = value; this.OnPropertyChanged("Price"); }
        }

        public double Spend
        {
            get { return this.spend; }
            set { this.spend = value; this.OnPropertyChanged("Spend"); }
        }

        public int Quantity
        {
            get { return this.quantity; }
            set { this.quantity = value; this.OnPropertyChanged("Quantity"); }
        }

        public int Id
        {
            get { return this.id; }
            set { this.id = value; this.OnPropertyChanged("Id"); }
        }

        protected virtual void OnPropertyChanged(string name)
        {
        }
    }
}
